@@ -752,7 +752,7 @@ pub extern "C" fn real_statistics_split32(vector: &VecBuf,
                                           data: *mut Statistics<f32>,
                                           len: usize)
                                           -> i32 {
-    let mut data = unsafe { slice::from_raw_parts_mut(data, len) };
+    let data = unsafe { slice::from_raw_parts_mut(data, len) };
     let vec = &vector.vec as &StatisticsSplitOps<f32, Result = StatsVec<Statistics<f32>>>;
     let stats = vec.statistics_split(data.len());
     match stats {
@@ -772,7 +772,7 @@ pub extern "C" fn complex_statistics_split32(vector: &VecBuf,
                                              data: *mut Statistics<Complex32>,
                                              len: usize)
                                              -> i32 {
-    let mut data = unsafe { slice::from_raw_parts_mut(data, len) };
+    let data = unsafe { slice::from_raw_parts_mut(data, len) };
     let vec = &vector.vec as &StatisticsSplitOps<Complex32,
                                                  Result = StatsVec<Statistics<Complex32>>>;
     let stats = vec.statistics_split(data.len());
@@ -793,7 +793,7 @@ pub extern "C" fn real_statistics_split_prec32(vector: &VecBuf,
                                                data: *mut Statistics<f64>,
                                                len: usize)
                                                -> i32 {
-    let mut data = unsafe { slice::from_raw_parts_mut(data, len) };
+    let data = unsafe { slice::from_raw_parts_mut(data, len) };
     let vec = &vector.vec as &PreciseStatisticsSplitOps<f64, Result = StatsVec<Statistics<f64>>>;
     let stats = vec.statistics_split_prec(data.len());
     match stats {
@@ -813,7 +813,7 @@ pub extern "C" fn complex_statistics_split_prec32(vector: &VecBuf,
                                                   data: *mut Statistics<Complex64>,
                                                   len: usize)
                                                   -> i32 {
-    let mut data = unsafe { slice::from_raw_parts_mut(data, len) };
+    let data = unsafe { slice::from_raw_parts_mut(data, len) };
     let vec = &vector.vec as &PreciseStatisticsSplitOps<Complex64,
                                                         Result = StatsVec<Statistics<Complex64>>>;
     let stats = vec.statistics_split_prec(data.len());
