@@ -753,7 +753,7 @@ pub extern "C" fn real_statistics_split64(vector: &VecBuf,
                                           data: *mut Statistics<f64>,
                                           len: usize)
                                           -> i32 {
-    let mut data = unsafe { slice::from_raw_parts_mut(data, len) };
+    let data = unsafe { slice::from_raw_parts_mut(data, len) };
     let vec = &vector.vec as &StatisticsSplitOps<f64, Result = StatsVec<Statistics<f64>>>;
     let stats = vec.statistics_split(data.len());
     match stats {
@@ -773,7 +773,7 @@ pub extern "C" fn complex_statistics_split64(vector: &VecBuf,
                                              data: *mut Statistics<Complex64>,
                                              len: usize)
                                              -> i32 {
-    let mut data = unsafe { slice::from_raw_parts_mut(data, len) };
+    let data = unsafe { slice::from_raw_parts_mut(data, len) };
     let vec = &vector.vec as &StatisticsSplitOps<Complex64,
                                                  Result = StatsVec<Statistics<Complex64>>>;
     let stats = vec.statistics_split(data.len());
@@ -794,7 +794,7 @@ pub extern "C" fn real_statistics_split_prec64(vector: &VecBuf,
                                                data: *mut Statistics<f64>,
                                                len: usize)
                                                -> i32 {
-    let mut data = unsafe { slice::from_raw_parts_mut(data, len) };
+    let data = unsafe { slice::from_raw_parts_mut(data, len) };
     let vec = &vector.vec as &PreciseStatisticsSplitOps<f64, Result = StatsVec<Statistics<f64>>>;
     let stats = vec.statistics_split_prec(data.len());
     match stats {
@@ -814,7 +814,7 @@ pub extern "C" fn complex_statistics_split_prec64(vector: &VecBuf,
                                                   data: *mut Statistics<Complex64>,
                                                   len: usize)
                                                   -> i32 {
-    let mut data = unsafe { slice::from_raw_parts_mut(data, len) };
+    let data = unsafe { slice::from_raw_parts_mut(data, len) };
     let vec = &vector.vec as &PreciseStatisticsSplitOps<Complex64,
                                                         Result = StatsVec<Statistics<Complex64>>>;
     let stats = vec.statistics_split_prec(data.len());
